@@ -50,7 +50,7 @@ APP_ICON = 'pg-icon'
 
 # Application version number components
 APP_RELEASE = 4
-APP_REVISION = 12
+APP_REVISION = 13
 
 # Application version suffix, e.g. 'beta1', 'dev'. Usually an empty string
 # for GA releases.
@@ -59,7 +59,7 @@ APP_SUFFIX = ''
 # Numeric application version for upgrade checks. Should be in the format:
 # [X]XYYZZ, where X is the release version, Y is the revision, with a leading
 # zero if needed, and Z represents the suffix, with a leading zero if needed
-APP_VERSION_INT = 41200
+APP_VERSION_INT = 41300
 
 # DO NOT CHANGE!
 # The application version string, constructed from the components
@@ -85,6 +85,7 @@ LANGUAGES = {
     'zh': 'Chinese (Simplified)',
     'fr': 'French',
     'de': 'German',
+    'it': 'Italian',
     'ja': 'Japanese',
     'ko': 'Korean',
     'pl': 'Polish',
@@ -163,6 +164,9 @@ SECURITY_PASSWORD_HASH = 'pbkdf2_sha512'
 #       has no effect on <= Python 2.7.
 MINIFY_PAGE = True
 
+# Set the cache control max age for static files in flask to 1 year
+SEND_FILE_MAX_AGE_DEFAULT = 31556952
+
 # This will be added to static urls as url parameter with value as
 # APP_VERSION_INT for cache busting on version upgrade. If the value is set as
 # None or empty string then it will not be added.
