@@ -178,6 +178,7 @@ define('pgadmin.node.function', [
           procost: undefined, /* Estimated execution Cost */
           prorows: undefined, /* Estimated number of rows */
           proleakproof: undefined,
+          prosupportfunc: undefined, /* Support function */
           arguments: [],
           prosrc: undefined,
           prosrc_c: undefined,
@@ -221,7 +222,7 @@ define('pgadmin.node.function', [
           type: 'text', group: gettext('Definition'), mode: ['properties'],
         },{
           id: 'proargs', label: gettext('Arguments'), cell: 'string',
-          type: 'text', group: gettext('Definition'), mode: ['properties', 'edit'],
+          type: 'text', group: gettext('Definition'), mode: ['properties'],
           disabled: 'isDisabled',
         },{
           id: 'proargtypenames', label: gettext('Signature arguments'), cell:
@@ -243,8 +244,9 @@ define('pgadmin.node.function', [
         },{
           id: 'prosrc', label: gettext('Code'), cell: 'string',
           type: 'text', mode: ['properties', 'create', 'edit'],
-          group: gettext('Definition'), deps: ['lanname'],
-          control: Backform.SqlFieldControl,
+          group: gettext('Code'), deps: ['lanname'],
+          tabPanelCodeClass: 'sql-code-control',
+          control: Backform.SqlCodeControl,
           extraClasses:['custom_height_css_class'],
           visible: function(m) {
             if (m.get('lanname') == 'c') {
@@ -312,12 +314,18 @@ define('pgadmin.node.function', [
           id: 'proleakproof', label: gettext('Leak proof?'),
           group: gettext('Options'), cell:'boolean', type: 'switch', min_version: 90200,
           disabled: 'isDisabled', deps: ['lanname'],
+        },{
+          id: 'prosupportfunc', label: gettext('Support function'),
+          type: 'text', disabled: 'isDisabled',
+          group: gettext('Options'), visible: 'isVisible',
+          control: 'node-ajax-options', url: 'get_support_functions',
+          cache_node: 'function', min_version: 120000,
         },{
           id: 'proacl', label: gettext('Privileges'), type: 'text',
           mode: ['properties'], group: gettext('Security'),
         },{
           id: 'arguments', label: gettext('Arguments'), cell: 'string',
-          group: gettext('Arguments'), type: 'collection', canAdd: function(m){
+          group: gettext('Definition'), type: 'collection', canAdd: function(m){
             return m.isNew();
           },
           canDelete: true, model: ArgumentModel, mode: ['create', 'edit'],
@@ -440,6 +448,11 @@ define('pgadmin.node.function', [
               return false;
             }
             return true;
+          case 'prosupportfunc':
+            var item = pgAdmin.Browser.tree.selected();
+            if(pgAdmin.Browser.Nodes['function'].getTreeNodeHierarchy(item).server.user.is_superuser)
+              return false;
+            return true;
           default:
             return false;
           }
