@@ -30,7 +30,7 @@ from pgadmin.utils.driver import get_driver
 from pgadmin.utils.exception import ConnectionLost, SSHTunnelConnectionLost
 from pgadmin.utils.preferences import Preferences
 from pgadmin.settings import get_setting
-from pgadmin.browser.utils import underscore_escape
+from pgadmin.browser.utils import underscore_unescape
 
 
 query_tool_close_session_lock = Lock()
@@ -114,13 +114,13 @@ def show_filter():
 
 
 @blueprint.route(
-    '/initialize/datagrid/<int:cmd_type>/<obj_type>/<int:sgid>/<int:sid>/'
-    '<int:did>/<int:obj_id>',
+    '/initialize/datagrid/<int:trans_id>/<int:cmd_type>/<obj_type>/'
+    '<int:sgid>/<int:sid>/<int:did>/<int:obj_id>',
     methods=["PUT", "POST"],
     endpoint="initialize_datagrid"
 )
 @login_required
-def initialize_datagrid(cmd_type, obj_type, sgid, sid, did, obj_id):
+def initialize_datagrid(trans_id, cmd_type, obj_type, sgid, sid, did, obj_id):
     """
     This method is responsible for creating an asynchronous connection.
     After creating the connection it will instantiate and initialize
@@ -183,9 +183,6 @@ def initialize_datagrid(cmd_type, obj_type, sgid, sid, did, obj_id):
         app.logger.error(e)
         return internal_server_error(errormsg=str(e))
 
-    # Create a unique id for the transaction
-    trans_id = str(random.randint(1, 9999999))
-
     if 'gridData' not in session:
         sql_grid_data = dict()
     else:
@@ -193,7 +190,7 @@ def initialize_datagrid(cmd_type, obj_type, sgid, sid, did, obj_id):
 
     # Use pickle to store the command object which will be used later by the
     # sql grid module.
-    sql_grid_data[trans_id] = {
+    sql_grid_data[str(trans_id)] = {
         # -1 specify the highest protocol version available
         'command_obj': pickle.dumps(command_obj, -1)
     }
@@ -203,51 +200,34 @@ def initialize_datagrid(cmd_type, obj_type, sgid, sid, did, obj_id):
 
     return make_json_response(
         data={
-            'gridTransId': trans_id
+            'conn_id': conn_id
         }
     )
 
 
 @blueprint.route(
-    '/panel/<int:trans_id>/<is_query_tool>/<path:editor_title>',
-    methods=["GET"],
+    '/panel/<int:trans_id>',
+    methods=["POST"],
     endpoint='panel'
 )
-def panel(trans_id, is_query_tool, editor_title):
+def panel(trans_id):
     """
     This method calls index.html to render the data grid.
 
     Args:
         trans_id: unique transaction id
-        is_query_tool: True if panel calls when query tool menu is clicked.
-        editor_title: Title of the editor
     """
-    # Let's fetch Script type URL from request
-    if request.args and request.args['query_url'] != '':
-        sURL = request.args['query_url']
-    else:
-        sURL = None
 
-    # Fetch server type from request
-    if request.args and request.args['server_type'] != '':
-        server_type = request.args['server_type']
-    else:
-        server_type = None
+    url_params = None
+    if request.args:
+        url_params = {k: v for k, v in request.args.items()}
 
-    if request.args and 'server_ver' in request.args:
-        server_ver = request.args['server_ver']
-    else:
-        server_ver = 0
-
-    # If title has slash(es) in it then replace it
-    if request.args and request.args['fslashes'] != '':
-        try:
-            fslashesList = request.args['fslashes'].split(',')
-            for idx in fslashesList:
-                idx = int(idx)
-                editor_title = editor_title[:idx] + '/' + editor_title[idx:]
-        except IndexError as e:
-            app.logger.exception(e)
+    if request.form:
+        url_params['title'] = request.form['title']
+        if 'sql_filter' in request.form:
+            url_params['sql_filter'] = request.form['sql_filter']
+        if 'query_url' in request.form:
+            url_params['query_url'] = request.form['query_url']
 
     # We need client OS information to render correct Keyboard shortcuts
     user_agent = UserAgent(request.headers.get('User-Agent'))
@@ -277,64 +257,43 @@ def panel(trans_id, is_query_tool, editor_title):
     # Fetch the server details
     bgcolor = None
     fgcolor = None
-    if 'gridData' in session and str(trans_id) in session['gridData']:
-        # Fetch the object for the specified transaction id.
-        # Use pickle.loads function to get the command object
-        session_obj = session['gridData'][str(trans_id)]
-        trans_obj = pickle.loads(session_obj['command_obj'])
-        s = Server.query.filter_by(id=trans_obj.sid).first()
-        if s and s.bgcolor:
-            # If background is set to white means we do not have to change
-            # the title background else change it as per user specified
-            # background
-            if s.bgcolor != '#ffffff':
-                bgcolor = s.bgcolor
-            fgcolor = s.fgcolor or 'black'
+
+    s = Server.query.filter_by(id=url_params['sid']).first()
+    if s and s.bgcolor:
+        # If background is set to white means we do not have to change
+        # the title background else change it as per user specified
+        # background
+        if s.bgcolor != '#ffffff':
+            bgcolor = s.bgcolor
+        fgcolor = s.fgcolor or 'black'
 
     layout = get_setting('SQLEditor/Layout')
 
-    url_params = dict()
-    if is_query_tool == 'true':
-        url_params['sgid'] = trans_obj.sgid
-        url_params['sid'] = trans_obj.sid
-        url_params['did'] = trans_obj.did
-    else:
-        url_params['cmd_type'] = trans_obj.cmd_type
-        url_params['obj_type'] = trans_obj.object_type
-        url_params['sgid'] = trans_obj.sgid
-        url_params['sid'] = trans_obj.sid
-        url_params['did'] = trans_obj.did
-        url_params['obj_id'] = trans_obj.obj_id
-
     return render_template(
         "datagrid/index.html",
         _=gettext,
         uniqueId=trans_id,
-        is_query_tool=is_query_tool,
-        editor_title=underscore_escape(editor_title),
-        script_type_url=sURL,
         is_desktop_mode=app.PGADMIN_RUNTIME,
         is_linux=is_linux_platform,
-        server_type=server_type,
-        server_ver=server_ver,
+        title=underscore_unescape(url_params['title']),
+        url_params=json.dumps(url_params),
         client_platform=user_agent.platform,
         bgcolor=bgcolor,
         fgcolor=fgcolor,
-        url_params=json.dumps(url_params),
         layout=layout,
     )
 
 
 @blueprint.route(
-    '/initialize/query_tool/<int:sgid>/<int:sid>/<int:did>',
+    '/initialize/query_tool/<int:trans_id>/<int:sgid>/<int:sid>/<int:did>',
     methods=["POST"], endpoint='initialize_query_tool_with_did'
 )
 @blueprint.route(
-    '/initialize/query_tool/<int:sgid>/<int:sid>',
+    '/initialize/query_tool/<int:trans_id>/<int:sgid>/<int:sid>',
     methods=["POST"], endpoint='initialize_query_tool'
 )
 @login_required
-def initialize_query_tool(sgid, sid, did=None):
+def initialize_query_tool(trans_id, sgid, sid, did=None):
     """
     This method is responsible for instantiating and initializing
     the query tool object. It will also create a unique
@@ -346,16 +305,16 @@ def initialize_query_tool(sgid, sid, did=None):
         did: Database Id
     """
     connect = True
-    reqArgs = None
     # Read the data if present. Skipping read may cause connection
     # reset error if data is sent from the client
     if request.data:
-        reqArgs = request.data
+        _ = request.data
 
     reqArgs = request.args
     if ('recreate' in reqArgs and
             reqArgs['recreate'] == '1'):
         connect = False
+
     # Create asynchronous connection using random connection id.
     conn_id = str(random.randint(1, 9999999))
 
@@ -389,9 +348,6 @@ def initialize_query_tool(sgid, sid, did=None):
         app.logger.error(e)
         return internal_server_error(errormsg=str(e))
 
-    # Create a unique id for the transaction
-    trans_id = str(random.randint(1, 9999999))
-
     if 'gridData' not in session:
         sql_grid_data = dict()
     else:
@@ -404,7 +360,7 @@ def initialize_query_tool(sgid, sid, did=None):
 
     # Use pickle to store the command object which will be used
     # later by the sql grid module.
-    sql_grid_data[trans_id] = {
+    sql_grid_data[str(trans_id)] = {
         # -1 specify the highest protocol version available
         'command_obj': pickle.dumps(command_obj, -1)
     }
@@ -414,7 +370,7 @@ def initialize_query_tool(sgid, sid, did=None):
 
     return make_json_response(
         data={
-            'gridTransId': trans_id,
+            'connId': str(conn_id),
             'serverVersion': manager.version,
         }
     )
