@@ -313,8 +313,8 @@ define([
         url: _url,
         cache: false,
       })
-        .done(function() {
-          self.start_global_debugger();
+        .done(function(res) {
+          self.start_global_debugger(args, item, res.data.trans_id);
         })
         .fail(function(xhr) {
           try {
@@ -329,7 +329,7 @@ define([
     },
 
     //Callback function when user start the indirect debugging ( Listen to another session to invoke the target )
-    start_global_debugger: function(args, item) {
+    start_global_debugger: function(args, item, trans_id) {
       // Initialize the target and create asynchronous connection and unique transaction ID
       var t = pgBrowser.tree,
         i = item || t.selected(),
@@ -343,48 +343,33 @@ define([
       var treeInfo = node.getTreeNodeHierarchy.apply(node, [i]),
         baseUrl;
 
-      if (d._type == 'function') {
+      if (d._type == 'function' || d._type == 'edbfunc') {
         baseUrl = url_for(
           'debugger.initialize_target_for_function', {
             'debug_type': 'indirect',
+            'trans_id': trans_id,
             'sid': treeInfo.server._id,
             'did': treeInfo.database._id,
             'scid': treeInfo.schema._id,
-            'func_id': treeInfo.function._id,
+            'func_id': debuggerUtils.getFunctionId(treeInfo),
           }
         );
-      } else if (d._type == 'procedure') {
+      } else if (d._type == 'procedure' || d._type == 'edbproc') {
         baseUrl = url_for(
           'debugger.initialize_target_for_function', {
             'debug_type': 'indirect',
+            'trans_id': trans_id,
             'sid': treeInfo.server._id,
             'did': treeInfo.database._id,
             'scid': treeInfo.schema._id,
             'func_id': debuggerUtils.getProcedureId(treeInfo),
           }
         );
-      } else if (d._type == 'edbfunc') {
-        // Get the existing function parameters available from sqlite database
-        baseUrl = url_for('debugger.initialize_target_for_function', {
-          'debug_type': 'indirect',
-          'sid': treeInfo.server._id,
-          'did': treeInfo.database._id,
-          'scid': treeInfo.schema._id,
-          'func_id': treeInfo.edbfunc._id,
-        });
-      } else if (d._type == 'edbproc') {
-        // Get the existing function parameters available from sqlite database
-        baseUrl = url_for('debugger.initialize_target_for_function', {
-          'debug_type': 'indirect',
-          'sid': treeInfo.server._id,
-          'did': treeInfo.database._id,
-          'scid': treeInfo.schema._id,
-          'func_id': treeInfo.edbproc._id,
-        });
       } else if (d._type == 'trigger_function') {
         baseUrl = url_for(
           'debugger.initialize_target_for_function', {
             'debug_type': 'indirect',
+            'trans_id': trans_id,
             'sid': treeInfo.server._id,
             'did': treeInfo.database._id,
             'scid': treeInfo.schema._id,
@@ -395,6 +380,7 @@ define([
         baseUrl = url_for(
           'debugger.initialize_target_for_trigger', {
             'debug_type': 'indirect',
+            'trans_id': trans_id,
             'sid': treeInfo.server._id,
             'did': treeInfo.database._id,
             'scid': treeInfo.schema._id,
@@ -406,6 +392,7 @@ define([
         baseUrl = url_for(
           'debugger.initialize_target_for_trigger', {
             'debug_type': 'indirect',
+            'trans_id': trans_id,
             'sid': treeInfo.server._id,
             'did': treeInfo.database._id,
             'scid': treeInfo.schema._id,
@@ -491,9 +478,11 @@ define([
       })
         .done(function(res) {
 
+          let debug_info = res.data.debug_info,
+            trans_id = res.data.trans_id;
           // Open Alertify the dialog to take the input arguments from user if function having input arguments
-          if (res.data[0]['require_input']) {
-            get_function_arguments(res.data[0], 0, is_edb_proc);
+          if (debug_info[0]['require_input']) {
+            get_function_arguments(debug_info[0], 0, is_edb_proc, trans_id);
           } else {
           // Initialize the target and create asynchronous connection and unique transaction ID
           // If there is no arguments to the functions then we should not ask for for function arguments and
@@ -509,20 +498,22 @@ define([
             var treeInfo = node.getTreeNodeHierarchy.apply(node, [i]),
               baseUrl;
 
-            if (d._type == 'function') {
+            if (d._type == 'function' || d._type == 'edbfunc') {
               baseUrl = url_for(
                 'debugger.initialize_target_for_function', {
                   'debug_type': 'direct',
+                  'trans_id': trans_id,
                   'sid': treeInfo.server._id,
                   'did': treeInfo.database._id,
                   'scid': treeInfo.schema._id,
-                  'func_id': treeInfo.function._id,
+                  'func_id': debuggerUtils.getFunctionId(treeInfo),
                 }
               );
-            } else {
+            } else if(d._type == 'procedure' || d._type == 'edbproc') {
               baseUrl = url_for(
                 'debugger.initialize_target_for_function', {
                   'debug_type': 'direct',
+                  'trans_id': trans_id,
                   'sid': treeInfo.server._id,
                   'did': treeInfo.database._id,
                   'scid': treeInfo.schema._id,
@@ -535,10 +526,10 @@ define([
               url: baseUrl,
               method: 'GET',
             })
-              .done(function(res) {
+              .done(function() {
 
                 var url = url_for('debugger.direct', {
-                  'trans_id': res.data.debuggerTransId,
+                  'trans_id': trans_id,
                 });
 
                 if (self.preferences.debugger_new_browser_tab) {
@@ -563,7 +554,7 @@ define([
                   // Register Panel Closed event
                   panel.on(wcDocker.EVENT.CLOSED, function() {
                     var closeUrl = url_for('debugger.close', {
-                      'trans_id': res.data.debuggerTransId,
+                      'trans_id': trans_id,
                     });
                     $.ajax({
                       url: closeUrl,
