@@ -39,6 +39,26 @@ define([
         this.trigger('pgDebugger:button:state:' + btn, enable);
       },
 
+      enable_toolbar_buttons: function() {
+        var self = this;
+        self.enable('stop', true);
+        self.enable('step_over', true);
+        self.enable('step_into', true);
+        self.enable('toggle_breakpoint', true);
+        self.enable('clear_all_breakpoints', true);
+        self.enable('continue', true);
+      },
+
+      disable_toolbar_buttons: function() {
+        var self = this;
+        self.enable('stop', false);
+        self.enable('step_over', false);
+        self.enable('step_into', false);
+        self.enable('toggle_breakpoint', false);
+        self.enable('clear_all_breakpoints', false);
+        self.enable('continue', false);
+      },
+
       /*
         Function to set the breakpoint and send the line no. which is set to server
         trans_id :- Unique Transaction ID, line_no - line no. to set the breakpoint,
@@ -405,12 +425,7 @@ define([
                     // Enable all the buttons as we got the results
                     // TODO: Fix this properly so a timeout isn't required.
                     setTimeout(function() {
-                      self.enable('stop', true);
-                      self.enable('step_over', true);
-                      self.enable('step_into', true);
-                      self.enable('continue', true);
-                      self.enable('toggle_breakpoint', true);
-                      self.enable('clear_all_breakpoints', true);
+                      self.enable_toolbar_buttons();
                     }, 500);
                   }
                 } else if (res.data.status === 'Busy') {
@@ -422,12 +437,7 @@ define([
                     );
 
                     // As we are waiting for another session to invoke the target,disable all the buttons
-                    self.enable('stop', false);
-                    self.enable('step_over', false);
-                    self.enable('step_into', false);
-                    self.enable('continue', false);
-                    self.enable('toggle_breakpoint', false);
-                    self.enable('clear_all_breakpoints', false);
+                    self.disable_toolbar_buttons();
                     pgTools.DirectDebug.first_time_indirect_debug = false;
                     self.poll_result(trans_id);
                   } else {
@@ -648,12 +658,7 @@ define([
         var self = this,
           baseUrl = url_for('debugger.restart', {'trans_id': trans_id});
 
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         // Clear msg tab
         pgTools.DirectDebug
@@ -725,12 +730,7 @@ define([
       // Continue the execution until the next breakpoint
       Continue: function(trans_id) {
         var self = this;
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         //Check first if previous execution was completed or not
         if (pgTools.DirectDebug.direct_execution_completed &&
@@ -767,12 +767,7 @@ define([
 
       Step_over: function(trans_id) {
         var self = this;
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         // Make ajax call to listen the database message
         var baseUrl = url_for('debugger.execute_query', {
@@ -803,12 +798,7 @@ define([
 
       Step_into: function(trans_id) {
         var self = this;
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         // Make ajax call to listen the database message
         var baseUrl = url_for('debugger.execute_query', {
@@ -839,12 +829,7 @@ define([
 
       Stop: function(trans_id) {
         var self = this;
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         // Make ajax call to listen the database message
         var baseUrl = url_for(
@@ -890,12 +875,7 @@ define([
 
       toggle_breakpoint: function(trans_id) {
         var self = this;
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
 
         var info = pgTools.DirectDebug.editor.lineInfo(self.active_line_no);
@@ -936,12 +916,8 @@ define([
                   return marker;
                 }());
               }
-              self.enable('stop', true);
-              self.enable('step_over', true);
-              self.enable('step_into', true);
-              self.enable('toggle_breakpoint', true);
-              self.enable('clear_all_breakpoints', true);
-              self.enable('continue', true);
+
+              self.enable_toolbar_buttons();
             } else if (res.data.status === 'NotConnected') {
               Alertify.alert(
                 gettext('Debugger Error'),
@@ -965,12 +941,7 @@ define([
         if ((br_list.length == 1) && (br_list[0].linenumber == -1))
           return;
 
-        self.enable('stop', false);
-        self.enable('step_over', false);
-        self.enable('step_into', false);
-        self.enable('toggle_breakpoint', false);
-        self.enable('clear_all_breakpoints', false);
-        self.enable('continue', false);
+        self.disable_toolbar_buttons();
 
         var breakpoint_list = new Array();
 
@@ -1004,12 +975,7 @@ define([
                 }
               }
             }
-            self.enable('stop', true);
-            self.enable('step_over', true);
-            self.enable('step_into', true);
-            self.enable('toggle_breakpoint', true);
-            self.enable('clear_all_breakpoints', true);
-            self.enable('continue', true);
+            self.enable_toolbar_buttons();
           })
           .fail(function() {
             Alertify.alert(
@@ -1513,17 +1479,17 @@ define([
       controller.Step_into(pgTools.DirectDebug.trans_id);
     },
     keyAction: function (event) {
-      var $el = this.$el, panel_id, actual_panel,
-        self = this;
+      let panel_type='';
 
-      panel_id = keyboardShortcuts.processEventDebugger(
-        $el, event, self.preferences
+      panel_type = keyboardShortcuts.processEventDebugger(
+        this.$el, event, this.preferences, pgTools.DirectDebug.docker
       );
 
-      // Panel navigation
-      if(!_.isUndefined(panel_id) && !_.isNull(panel_id)) {
-        actual_panel = panel_id + 1;
-        pgTools.DirectDebug.docker.findPanels()[actual_panel].focus();
+
+      if(!_.isNull(panel_type) && !_.isUndefined(panel_type) && panel_type != '') {
+        setTimeout(function() {
+          pgBrowser.Events.trigger(`pgadmin:debugger:${panel_type}:focus`);
+        }, 100);
       }
     },
   });
@@ -1561,7 +1527,7 @@ define([
 
       let browser = window.opener ?
         window.opener.pgAdmin.Browser : window.top.pgAdmin.Browser;
-      this.preferences = browser.get_preferences_for_module('sqleditor');
+      this.preferences = browser.get_preferences_for_module('debugger');
 
       this.docker = new wcDocker(
         '#container', {
@@ -1575,8 +1541,6 @@ define([
         });
       this.panels = [];
 
-      pgBrowser.bind_beforeunload();
-
       // Below code will be executed for indirect debugging
       // indirect debugging - 0  and for direct debugging - 1
       if (trans_id != undefined && !debug_type) {
@@ -1592,6 +1556,7 @@ define([
           .done(function(res) {
             if (res.data.status) {
               self.intializePanels();
+              controller.enable_toolbar_buttons();
               controller.poll_result(trans_id);
             }
           })
@@ -1656,6 +1621,7 @@ define([
         .done(function(res) {
           if (res.data.status === 'Success') {
             self.intializePanels();
+            controller.enable_toolbar_buttons();
             // If status is Success then find the port number to attach the executer.
             controller.start_execution(trans_id, res.data.result);
           } else if (res.data.status === 'Busy') {
@@ -1826,14 +1792,7 @@ define([
           foldOptions: {
             widget: '\u2026',
           },
-          foldGutter: {
-            rangeFinder: CodeMirror.fold.combine(
-              CodeMirror.pgadminBeginRangeFinder,
-              CodeMirror.pgadminIfRangeFinder,
-              CodeMirror.pgadminLoopRangeFinder,
-              CodeMirror.pgadminCaseRangeFinder
-            ),
-          },
+          foldGutter: true,
           gutters: [
             'CodeMirror-linenumbers', 'CodeMirror-foldgutter', 'breakpoints',
           ],
@@ -1856,6 +1815,10 @@ define([
         }
       });
 
+      pgBrowser.Events.on('pgadmin:debugger:code:focus', ()=>{
+        self.editor.focus();
+      });
+
       // On loading the docker, register the callbacks
       var onLoad = function() {
         self.docker.finishLoading(100);
@@ -1881,6 +1844,7 @@ define([
                * instead, a poller is set up who will check
                */
               if(self.preferences.debugger_new_browser_tab) {
+                pgBrowser.bind_beforeunload();
                 let pollIntervalId = setInterval(()=>{
                   if(window.opener && window.opener.pgAdmin) {
                     self.reflectPreferences();
@@ -1906,6 +1870,16 @@ define([
       // Create the toolbar view for debugging the function
       this.toolbarView = new DebuggerToolbarView();
 
+      /* wcDocker focuses on window always, and all our shortcuts are
+       * bind to editor-panel. So when we use wcDocker focus, editor-panel
+       * loses focus and events don't work.
+       */
+      $(window).on('keydown', (e)=>{
+        if(self.toolbarView.keyAction) {
+          self.toolbarView.keyAction(e);
+        }
+      });
+
       /* Cache may take time to load for the first time
        * Keep trying till available
        */
