@@ -32,9 +32,9 @@ class TestUtilityCheckRouteCase(BaseTestGenerator):
     def setUp(self):
         check_binary_path_or_skip_test(self, 'psql')
 
-    @patch('pgadmin.tools.maintenance.is_utility_exists')
-    def runTest(self, is_utility_exists_mock):
-        is_utility_exists_mock.return_value = False
+    @patch('pgadmin.tools.maintenance.does_utility_exist')
+    def runTest(self, does_utility_exist_mock):
+        does_utility_exist_mock.return_value = False
         server_id = self.server_information['server_id']
         response = self.tester.get(self.url.format(server_id))
         self.assertEquals(response.status_code, 200)
