@@ -9,7 +9,6 @@
 from __future__ import print_function
 import json
 import os
-import urllib
 import traceback
 from flask import url_for
 import regression
@@ -21,14 +20,26 @@ from pgadmin.browser.server_groups.servers.databases.tests import \
 from pgadmin.utils.versioned_template_loader import \
     get_version_mapping_directories
 
+# import urlencode from urlib for python2.x and python3.x
+try:
+    from urllib import urlencode
+except Exception as e:
+    from urllib.parse import urlencode
 
-def create_resql_module_list(all_modules, exclude_pkgs):
+try:
+    basestring
+except NameError:
+    basestring = str
+
+
+def create_resql_module_list(all_modules, exclude_pkgs, for_modules):
     """
     This function is used to create the module list for reverse engineered
     SQL by iterating all the modules.
 
     :param all_modules: List of all the modules
     :param exclude_pkgs: List of exclude packages
+    :param for_modules: Module list
     :return:
     """
     resql_module_list = dict()
@@ -41,7 +52,13 @@ def create_resql_module_list(all_modules, exclude_pkgs):
             module_name_list = complete_module_name[0].split(".")
             module_name = module_name_list[len(module_name_list) - 1]
 
-            resql_module_list[module_name] = os.path.join(*module_name_list)
+            if len(for_modules) > 0:
+                if module_name in for_modules:
+                    resql_module_list[module_name] = \
+                        os.path.join(*module_name_list)
+            else:
+                resql_module_list[module_name] = \
+                    os.path.join(*module_name_list)
 
     return resql_module_list
 
@@ -72,6 +89,8 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
         self.apppath = os.getcwd()
         # Status of the test case
         self.final_test_status = True
+        self.parent_ids = dict()
+        self.all_object_ids = dict()
 
         # Added line break after scenario name
         print("")
@@ -83,14 +102,15 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
         # Schema ID placeholder in JSON file which needs to be replaced
         # while running the test cases
         self.JSON_PLACEHOLDERS = {'schema_id': '<SCHEMA_ID>',
-                                  'owner': '<OWNER>'}
+                                  'owner': '<OWNER>',
+                                  'timestamptz': '<TIMESTAMPTZ>'}
 
         resql_module_list = create_resql_module_list(
             BaseTestGenerator.re_sql_module_list,
-            BaseTestGenerator.exclude_pkgs)
+            BaseTestGenerator.exclude_pkgs,
+            getattr(BaseTestGenerator, 'for_modules', []))
 
         for module in resql_module_list:
-            self.table_id = None
             module_path = resql_module_list[module]
             # Get the folder name based on server version number and
             # their existence.
@@ -117,6 +137,10 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                         for key, scenarios in data.items():
                             self.execute_test_case(scenarios)
 
+                        # Clear the parent ids stored for one json file.
+                        self.parent_ids.clear()
+                        self.all_object_ids.clear()
+
         # Check the final status of the test case
         self.assertEqual(self.final_test_status, True)
 
@@ -159,9 +183,21 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                 elif arg == 'did':
                     options['did'] = int(self.server_information['db_id'])
                 elif arg == 'scid':
-                    options['scid'] = int(self.schema_id)
-                elif arg == 'tid' and self.table_id:
-                    options['tid'] = int(self.table_id)
+                    # For schema node object_id is the actual schema id.
+                    if endpoint.__contains__('NODE-schema') and \
+                            object_id is not None:
+                        options['scid'] = int(object_id)
+                    else:
+                        options['scid'] = int(self.schema_id)
+                # tid represents table oid
+                elif arg == 'tid' and 'tid' in self.parent_ids:
+                    options['tid'] = int(self.parent_ids['tid'])
+                # fid represents FDW oid
+                elif arg == 'fid' and 'fid' in self.parent_ids:
+                    options['fid'] = int(self.parent_ids['fid'])
+                # fsid represents Foreign Server oid
+                elif arg == 'fsid' and 'fsid' in self.parent_ids:
+                    options['fsid'] = int(self.parent_ids['fsid'])
                 else:
                     if object_id is not None:
                         options[arg] = int(object_id)
@@ -187,33 +223,31 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                       "... skipped (pre-condition SQL not satisfied)")
                 continue
 
+            # Check precondition for schema
+            self.check_schema_precondition(scenario)
+
+            # Preprocessed data to replace any place holder if available
+            if 'preprocess_data' in scenario and \
+                    scenario['preprocess_data'] and 'data' in scenario:
+                scenario['data'] = self.preprocess_data(scenario['data'])
+
+            # If msql_endpoint exists then validate the modified sql
+            if 'msql_endpoint' in scenario\
+                    and scenario['msql_endpoint']:
+                if not self.check_msql(scenario, object_id):
+                    print_msg = scenario['name']
+                    if 'expected_msql_file' in scenario:
+                        print_msg += "  Expected MSQL File:" + scenario[
+                            'expected_msql_file']
+                    print_msg = print_msg + "... FAIL"
+                    print(print_msg)
+                    continue
+                else:
+                    print(scenario['name'] + " (MSQL) ... ok")
+
             if 'type' in scenario and scenario['type'] == 'create':
                 # Get the url and create the specific node.
 
-                if 'data' in scenario and 'schema' in scenario['data']:
-                    # If schema is already exist then fetch the oid
-                    self.get_db_connection()
-                    schema = regression.schema_utils.verify_schemas(
-                        self.server, self.db_name,
-                        scenario['data']['schema']
-                    )
-
-                    if schema:
-                        self.schema_id = schema[0]
-                    else:
-                        # If schema doesn't exist then create it
-                        schema = regression.schema_utils.create_schema(
-                            self.connection,
-                            scenario['data']['schema'])
-                        self.schema_id = schema[0]
-                else:
-                    self.schema_id = self.server_information['schema_id']
-
-                if 'data' in scenario and 'schema_id' in scenario['data'] and \
-                        scenario['data']['schema_id'] == \
-                        self.JSON_PLACEHOLDERS['schema_id']:
-                    scenario['data']['schema'] = self.schema_id
-
                 create_url = self.get_url(scenario['endpoint'])
                 response = self.tester.post(create_url,
                                             data=json.dumps(scenario['data']),
@@ -229,9 +263,11 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                 resp_data = json.loads(response.data.decode('utf8'))
                 object_id = resp_data['node']['_id']
 
-                # Table child nodes require table id
-                if 'store_table_id' in scenario:
-                    self.table_id = object_id
+                # Store the object id based on endpoints
+                if 'store_object_id' in scenario:
+                    self.store_object_ids(object_id,
+                                          scenario['data']['name'],
+                                          scenario['endpoint'])
 
                 # Compare the reverse engineering SQL
                 if not self.check_re_sql(scenario, object_id):
@@ -246,18 +282,6 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
             elif 'type' in scenario and scenario['type'] == 'alter':
                 # Get the url and create the specific node.
 
-                # If msql_endpoint exists then validate the modified sql
-                if 'msql_endpoint' in scenario\
-                        and scenario['msql_endpoint']:
-                    if not self.check_msql(scenario, object_id):
-                        print_msg = scenario['name']
-                        if 'expected_msql_file' in scenario:
-                            print_msg += "  Expected MSQL File:" + scenario[
-                                'expected_msql_file']
-                        print_msg = print_msg + "... FAIL"
-                        print(print_msg)
-                        continue
-
                 alter_url = self.get_url(scenario['endpoint'], object_id)
                 response = self.tester.put(alter_url,
                                            data=json.dumps(scenario['data']),
@@ -341,7 +365,15 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
         msql_url = self.get_url(scenario['msql_endpoint'],
                                 object_id)
 
-        params = urllib.parse.urlencode(scenario['data'])
+        # As msql data is passed as URL params, dict, list types data has to
+        # be converted to string using json.dumps before passing it to
+        # urlencode
+        msql_data = {
+            key: json.dumps(val)
+            if isinstance(val, dict) or isinstance(val, list) else val
+            for key, val in scenario['data'].items()}
+
+        params = urlencode(msql_data)
         params = params.replace('False', 'false').replace('True', 'true')
         url = msql_url + "?%s" % params
         response = self.tester.get(url,
@@ -352,6 +384,7 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
             self.final_test_status = False
             print(scenario['name'] + "... FAIL")
             traceback.print_exc()
+            return False
         try:
             if type(response.data) == bytes:
                 response_data = response.data.decode('utf8')
@@ -361,11 +394,14 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
             resp_sql = resp['data']
         except Exception:
             print("Unable to decode the response data from url: ", url)
+            return False
 
         # Remove first and last double quotes
         if resp_sql.startswith('"') and resp_sql.endswith('"'):
             resp_sql = resp_sql[1:-1]
-            resp_sql = resp_sql.rstrip()
+
+        # Remove triling \n
+        resp_sql = resp_sql.rstrip()
 
         # Check if expected sql is given in JSON file or path of the output
         # file is given
@@ -382,6 +418,9 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                 if 'username' in self.server:
                     sql = sql.replace(self.JSON_PLACEHOLDERS['owner'],
                                       self.server['username'])
+                # Convert timestamp with timezone from json file to the
+                # database server's correct timestamp
+                sql = self.convert_timestamptz(scenario, sql)
                 try:
                     self.assertEquals(sql, resp_sql)
                 except Exception as e:
@@ -390,7 +429,7 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                     return False
             else:
                 try:
-                    self.assertFalse("Expected SQL File not found")
+                    self.assertFalse("Expected Modified SQL File not found")
                 except Exception as e:
                     self.final_test_status = False
                     traceback.print_exc()
@@ -421,7 +460,9 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
         # Remove first and last double quotes
         if resp_sql.startswith('"') and resp_sql.endswith('"'):
             resp_sql = resp_sql[1:-1]
-            resp_sql = resp_sql.rstrip()
+
+        # Remove triling \n
+        resp_sql = resp_sql.rstrip()
 
         # Check if expected sql is given in JSON file or path of the output
         # file is given
@@ -438,6 +479,9 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
                 if 'username' in self.server:
                     sql = sql.replace(self.JSON_PLACEHOLDERS['owner'],
                                       self.server['username'])
+                # Convert timestamp with timezone from json file to the
+                # database server's correct timestamp
+                sql = self.convert_timestamptz(scenario, sql)
                 try:
                     self.assertEquals(sql, resp_sql)
                 except Exception as e:
@@ -458,6 +502,9 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
             if 'username' in self.server:
                 exp_sql = exp_sql.replace(self.JSON_PLACEHOLDERS['owner'],
                                           self.server['username'])
+            # Convert timestamp with timezone from json file to the
+            # database server's correct timestamp
+            sql = self.convert_timestamptz(scenario, exp_sql)
             try:
                 self.assertEquals(exp_sql, resp_sql)
             except Exception as e:
@@ -485,3 +532,126 @@ class ReverseEngineeredSQLTestCases(BaseTestGenerator):
             traceback.print_exc()
         pg_cursor.close()
         return precondition_flag
+
+    def check_schema_precondition(self, scenario):
+        """
+        This function will check the given schema is exist or not. If exist
+        then fetch the oid and if not then create it.
+
+        :param scenario:
+        :return:
+        """
+        if 'type' in scenario and scenario['type'] == 'create':
+            # Get the url and create the specific node.
+
+            if 'data' in scenario and 'schema' in scenario['data']:
+                # If schema is already exist then fetch the oid
+                self.get_db_connection()
+                schema = regression.schema_utils.verify_schemas(
+                    self.server, self.db_name,
+                    scenario['data']['schema']
+                )
+
+                if schema:
+                    self.schema_id = schema[0]
+                else:
+                    # If schema doesn't exist then create it
+                    schema = regression.schema_utils.create_schema(
+                        self.connection,
+                        scenario['data']['schema'])
+                    self.schema_id = schema[0]
+            else:
+                self.schema_id = self.server_information['schema_id']
+
+            if 'data' in scenario and 'schema_id' in scenario['data'] and \
+                scenario['data']['schema_id'] == \
+                    self.JSON_PLACEHOLDERS['schema_id']:
+                scenario['data']['schema'] = self.schema_id
+
+    def convert_timestamptz(self, scenario, sql):
+        """
+        This function will convert the given timestamptz with database
+        servers timestamptz and replace that in given sql.
+        :param scenario:
+        :param sql:
+        :return:
+        """
+        if 'convert_timestamp_columns' in scenario:
+            for col in scenario['convert_timestamp_columns']:
+                if 'data' in scenario and col in scenario['data']:
+                    self.get_db_connection()
+                    pg_cursor = self.connection.cursor()
+                    try:
+                        query = "SELECT timestamp with time zone '" \
+                                + scenario['data'][col] + "'"
+                        pg_cursor.execute(query)
+                        converted_tz = pg_cursor.fetchone()
+                        if len(converted_tz) >= 1:
+                            sql = sql.replace(
+                                self.JSON_PLACEHOLDERS['timestamptz'],
+                                converted_tz[0])
+                    except Exception as e:
+                        traceback.print_exc()
+                    pg_cursor.close()
+
+        return sql
+
+    def store_object_ids(self, object_id, object_name, endpoint):
+        """
+        This functions will store the object id based on endpoints
+        :param object_id: Object id of the created node
+        :param object_name: Object name
+        :param endpoint:
+        :return:
+        """
+        if endpoint.__contains__("NODE-table"):
+            self.parent_ids['tid'] = object_id
+        elif endpoint.__contains__("NODE-foreign_data_wrapper"):
+            self.parent_ids['fid'] = object_id
+        elif endpoint.__contains__("NODE-foreign_server"):
+            self.parent_ids['fsid'] = object_id
+
+        # Store object id with object name
+        self.all_object_ids[object_name] = object_id
+
+    def preprocess_data(self, data):
+        """
+        This function iterate through data and check for any place holder
+        starts with '<' and ends with '>' and replace with respective object
+        ids.
+        :param data: Data
+        :return:
+        """
+
+        if isinstance(data, dict):
+            for key, val in data.items():
+                if isinstance(val, dict) or isinstance(val, list):
+                    data[key] = self.preprocess_data(val)
+                else:
+                    data[key] = self.replace_placeholder_with_id(val)
+        elif isinstance(data, list):
+            ret_list = []
+            for item in data:
+                if isinstance(item, dict) or isinstance(item, list):
+                    ret_list.append(self.preprocess_data(item))
+                else:
+                    ret_list.append(self.replace_placeholder_with_id(item))
+            return ret_list
+
+        return data
+
+    def replace_placeholder_with_id(self, value):
+        """
+        This function is used to replace the place holder with id.
+        :param value:
+        :return:
+        """
+
+        if isinstance(value, basestring) and \
+                value.startswith('<') and value.endswith('>'):
+            # Remove < and > from the string
+            temp_value = value[1:-1]
+            # Find the place holder OID in dictionary
+            if temp_value in self.all_object_ids:
+                return self.all_object_ids[temp_value]
+        return value
