@@ -26,7 +26,6 @@ const extractStyle = new MiniCssExtractPlugin({
 });
 const envType = PRODUCTION ? 'production': 'development';
 const devToolVal = PRODUCTION ? false : 'eval';
-const HardSourceWebpackPlugin = require('hard-source-webpack-plugin');
 
 // Expose libraries in app context so they need not to
 // require('libname') when used in a module
@@ -51,19 +50,6 @@ const optimizeAssetsPlugin = new OptimizeCssAssetsPlugin({
   canPrint: true,
 });
 
-// Manages the cache and stores it into 'sources/generated/.cache/<env><hash>/' path
-// where env = dev || prod
-const hardSourceWebpackPlugin = new HardSourceWebpackPlugin({
-  cacheDirectory: './.cache/hard-source/' + envType +'/[confighash]',
-  recordsPath: './.cache/hard-source/' + envType +'/[confighash]/records.json',
-  configHash: require('node-object-hash')({sort: false}).hash,
-  environmentHash: {
-    root: process.cwd(),
-    directories: ['node_modules'],
-    files: ['package.json'],
-  },
-});
-
 // Helps in debugging each single file, it extracts the module files
 // from bundle so that they are accessible by search in Chrome's sources panel.
 // Reference: https://webpack.js.org/plugins/source-map-dev-tool-plugin/#components/sidebar/sidebar.jsx
@@ -241,7 +227,8 @@ module.exports = {
         ',pgadmin.node.view' +
         ',pgadmin.node.mview' +
         ',pgadmin.node.table' +
-        ',pgadmin.node.partition',
+        ',pgadmin.node.partition' +
+        ',pgadmin.node.compound_trigger',
       },
     }, {
       test: require.resolve('./node_modules/acitree/js/jquery.aciTree.min'),
@@ -409,7 +396,6 @@ module.exports = {
   ]: [
     extractStyle,
     providePlugin,
-    hardSourceWebpackPlugin,
     sourceMapDevToolPlugin,
   ],
 };
